/**
 * Wolmart Theme Library
 * 
 * @package Wolmart WordPress theme
 * @version 1.0
 */
'use strict';

window.Wolmart || (window.Wolmart = {});

(function ($) {
	/**
	 * jQuery Window Object
	 * 
	 * @var {jQuery} $window
	 * @since 1.0
	 */
	Wolmart.$window = $(window);

	/**
	 * jQuery Body Object
	 * 
	 * @var {jQuery} $body
	 * @since 1.0
	 */
	Wolmart.$body;

	/**
	 * Status
	 * 
	 * @var {string} status
	 * @since 1.0
	 */
	Wolmart.status = 'loading';

	/**
	 * Hash
	 * 
	 * @var {string} hash
	 * @since 1.0
	 */
	Wolmart.hash = location.hash.indexOf('&') > 0 ? location.hash.substring(0, location.hash.indexOf('&')) : location.hash;

	/**
	 * Detect Internet Explorer
	 * 
	 * @var {boolean} isIE
	 * @since 1.0
	 */
	Wolmart.isIE = navigator.userAgent.indexOf("Trident") >= 0;

	/**
	 * Detect Edge
	 * 
	 * @var {boolean} isEdge
	 * @since 1.0
	 */
	Wolmart.isEdge = navigator.userAgent.indexOf("Edge") >= 0;

	/**
	 * Detect Mobile
	 * 
	 * @var {boolean} isMobile
	 * @since 1.0
	 */
	Wolmart.isMobile = /Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent);

	/**
	 * Default options
	 * 
	 * @var {Object} defaults
	 * @since 1.0
	 */
	Wolmart.defaults = {
		stickySidebar: {
			autoInit: true,
			minWidth: 991,
			containerSelector: '.sticky-sidebar-wrapper',
			autoFit: true,
			activeClass: 'sticky-sidebar-fixed',
			padding: {
				top: 0,
				bottom: 0
			},
		},
		isotope: {
			itemsSelector: '.grid-item',
			layoutMode: 'masonry',
			percentPosition: true,
			masonry: {
				columnWidth: '.grid-space'
			},
			getSortData: {
				order: '[data-creative-order] parseInt',
				order_lg: '[data-creative-order-lg] parseInt',
				order_md: '[data-creative-order-md] parseInt',
			},
		},
		lazyload: {
			effect: 'fadeIn',
			data_attribute: 'lazy',
			data_srcset: 'lazyset',
			effect_speed: 400,
			failure_limit: 1000,
			event: 'scroll update_lazyload',
			load: function () {
				if ('IMG' == this.tagName) {
					this.style['padding-top'] = '';
					this.classList.remove('w-lazyload');
				} else {
					if (this.classList.contains('elementor-element-populated') || this.classList.contains('elementor-section')) {
						this.style['background-image'] = '';
					}
				}
				this.removeAttribute('data-lazy');
				this.removeAttribute('data-lazyset');
				this.removeAttribute('data-sizes');
			}
		},
		sticky: {
			minWidth: 992,
			maxWidth: 20000,
			top: false,
			bottomOrigin: false,
			// hide: false, // hide when it is not sticky.
			max_index: 1059, // maximum z-index of sticky contents
			scrollMode: false
		},
		animation: {
			name: 'fadeIn',
			duration: '1.2s',
			delay: '.2s'
		},
		stickyMobileBar: {
			minWidth: 0,
			maxWidth: 767,
			top: 150,
			// hide: true,
			scrollMode: true
		},
		stickyToolbox: {
			minWidth: 0,
			maxWidth: 767,
			scrollMode: true
		},
		minipopup: {
			content: '',
			delay: 4000, // milliseconds
		}
	};

	/**
	 * Create a macro task
	 *
	 * @since 1.0
	 * @param {function} fn  Function to handle task.
	 * @param {number} delay Delay time
	 * @return {void}
	 */
	Wolmart.call = function (fn, delay) {
		wolmart_vars.a || delay ? setTimeout(fn, delay) : fn();
	}

	/**
	 * Get DOM element by id
	 * 
	 * @since 1.0
	 * @param {string} id    ID attribute of element to find
	 * @return {HTMLElement} Matched element
	 */
	Wolmart.byId = function (id) {
		return document.getElementById(id);
	}

	/**
	 * Get DOM elements by tagName
	 * 
	 * @since 1.0
	 * @param {string} tagName   Tag name to find
	 * @param {HTMLElement} root Root element. This can be omitted.
	 * @return {HTMLCollection}
	 */
	Wolmart.byTag = function (tagName, root) {
		return (root ? root : document).getElementsByTagName(tagName);
	}

	/**
	 * Get DOM elements by className
	 * 
	 * @since 1.0
	 * @param {string} className Class name to find
	 * @param {HTMLElement} root Root elements
	 * @return {HTMLCollection}  Matched elements
	 */
	Wolmart.byClass = function (className, root) {
		return root ? root.getElementsByClassName(className) : document.getElementsByClassName(className);
	}

	/**
	 * Get jQuery object
	 * 
	 * @since 1.0
	 * @param {string|jQuery} selector	Selector to find
	 * @param {string|jQuery} find		Find from selector root
	 * @return {jQuery|Object}			jQuery Object or {each: $.noop}
	 */
	Wolmart.$ = function (selector, find) {
		if (typeof selector == 'string' && typeof find == 'string') {
			return $(selector + ' ' + find);
		}
		if (selector instanceof jQuery) {
			if (selector.is(find)) {
				return selector;
			}
			if (typeof find == 'undefined') {
				return selector;
			}
			return selector.find(find);
		}
		if (typeof selector == 'undefined' || !selector) {
			return $(find);
		}
		if (typeof find == 'undefined') {
			return $(selector);
		}
		return $(selector).find(find);
	}


	/**
	 * Get Cache Object
	 * 
	 * @since 1.0
	 * @return {Object} 
	 */
	Wolmart.getCache = function () {
		return localStorage[wolmart_vars.wolmart_cache_key] ? JSON.parse(localStorage[wolmart_vars.wolmart_cache_key]) : {};
	}

	/**
	 * Set Cache Object
	 * 
	 * @since 1.0
	 * @param {mixed} cache
	 * @return {void}
	 */
	Wolmart.setCache = function (cache) {
		localStorage[wolmart_vars.wolmart_cache_key] = JSON.stringify(cache);
	}

	/**
	 * Request timeout by using requestAnimationFrame
	 * 
	 * @since 1.0
	 * @param {function} fn
	 * @param {number} delay
	 * @return {Object} handle
	 */
	Wolmart.requestTimeout = function (fn, delay) {
		var handler = window.requestAnimationFrame || window.webkitRequestAnimationFrame || window.mozRequestAnimationFrame;
		if (!handler) {
			return setTimeout(fn, delay);
		}
		delay || (delay = 0);
		var start, rt = new Object();

		function loop(timestamp) {
			if (!start) {
				start = timestamp;
			}
			var progress = timestamp - start;
			progress >= delay ? fn() : rt.val = handler(loop);
		};

		rt.val = handler(loop);
		return rt;
	}

	/**
	 * Request frame by using requestAnimationFrame
	 * 
	 * @since 1.0
	 * @param {function} fn
	 * @return {Object} handle
	 */
	Wolmart.requestFrame = function (fn) {
		return { val: (window.requestAnimationFrame || window.webkitRequestAnimationFrame || window.mozRequestAnimationFrame)(fn) };
	}

	/**
	 * Request interval by using requestAnimationFrame
	 *
	 * @since 1.0
	 * @param {function} fn
	 * @param {number} step
	 * @param {number} timeOut
	 * @return {Object} handle
	 */
	Wolmart.requestInterval = function (fn, step, timeOut) {
		var handler = window.requestAnimationFrame || window.webkitRequestAnimationFrame || window.mozRequestAnimationFrame;
		if (!handler) {
			if (!timeOut)
				return setTimeout(fn, timeOut);
			else
				return setInterval(fn, step);
		}
		var start, last, rt = new Object();
		function loop(timestamp) {
			if (!start) {
				start = last = timestamp;
			}
			var progress = timestamp - start;
			var delta = timestamp - last;
			if (!timeOut || progress < timeOut) {
				if (delta > step) {
					rt.val = handler(loop);
					fn();
					last = timestamp;
				} else {
					rt.val = handler(loop);
				}
			} else {
				fn();
			}
		};
		rt.val = handler(loop);
		return rt;
	}

	/**
	 * Delete timeout by using requestAnimationFrame
	 * 
	 * @since 1.0
	 * @param {number} timerID
	 * @return {void}
	 */
	Wolmart.deleteTimeout = function (timerID) {
		if (!timerID) {
			return;
		}
		var handler = window.cancelAnimationFrame || window.webkitCancelAnimationFrame || window.mozCancelAnimationFrame;
		if (!handler) {
			return clearTimeout(timerID);
		}
		if (timerID.val) {
			return handler(timerID.val);
		}
	}

	function debounce(func, threshold, execAsap) {
		var timeout;
		return function debounced() {
			var obj = this, args = arguments;
			function delayed() {
				execAsap || func.apply(obj, args);
				timeout = null;
			}

			if (timeout)
				Wolmart.deleteTimeout(timeout);
			else if (execAsap)
				func.apply(obj, args);

			timeout = Wolmart.requestTimeout(delayed, threshold || 100);
		};
	};

	/**
	 * Smart resize
	 */
	$.fn.smartresize = function (fn) {
		fn ? this.get(0).addEventListener('resize', debounce(fn), { passive: true }) : this.trigger('smartresize');
	};

	/**
	 * Smart scroll
	 */
	$.fn.smartscroll = function (fn) {
		fn ? this.get(0).addEventListener('scroll', debounce(fn), { passive: true }) : this.trigger('smartscroll');
	};

	/**
	 * Parse options string to object
	 * 
	 * @since 1.0
	 * @param {string} options	Options string
	 * @return {object}
	 */
	Wolmart.parseOptions = function (options) {
		return 'string' == typeof options ? JSON.parse(options.replace(/'/g, '"').replace(';', '')) : {};
	}

	/**
	 * Check if given element is on screen
	 * 
	 * @since 1.0
	 * @param {HTMLElement} el
	 * @param {number} dx
	 * @param {number} dy
	 * @return {boolean}
	 */
	Wolmart.isOnScreen = function (el, dx, dy) {
		var a = window.pageXOffset,
			b = window.pageYOffset,
			o = el.getBoundingClientRect(),
			x = o.left + a,
			y = o.top + b,
			ax = typeof dx == 'undefined' ? 0 : dx,
			ay = typeof dy == 'undefined' ? 0 : dy;

		return y + o.height + ay >= b &&
			y <= b + window.innerHeight + ay &&
			x + o.width + ax >= a &&
			x <= a + window.innerWidth + ax;
	}


	/**
	 * Run appear animation
	 * 
	 * @since 1.0
	 * @param {HTMLElement} el DOM Element to appear
	 * @param {function} fn    Callback function
	 * @param {object} intObsOptions Options
	 * @return {void}
	 */
	Wolmart.appear = function (el, fn, intObsOptions) {

		var $this = $(el);

		if ($this.data('observer-init')) {
			return;
		}

		var interSectionObserverOptions = {
			rootMargin: '0px 0px 200px 0px',
			threshold: 0,
			alwaysObserve: true
		};

		if (intObsOptions && Object.keys(intObsOptions).length) {
			intersectionObserverOptions = $.extend(intersectionObserverOptions, intObsOptions);
		}

		var observer = new IntersectionObserver(function (entries) {
			for (var i = 0; i < entries.length; i++) {
				var entry = entries[i];

				if (entry.intersectionRatio > 0) {
					if (typeof fn === 'string') {
						var func = Function('return ' + functionName)();
					} else {
						var callback = fn;
						callback.call(entry.target);
					}
				}
			}
		}, interSectionObserverOptions);

		observer.observe(el);

		$this.data('observer-init', true);

		return this;
	}


	/**
	 * Fit posts' videos
	 *
	 * @since 1.0
	 * @param {string} selector
	 * @return {void}
	 */
	Wolmart.fitVideoSize = function (selector) {
		if ($.fn.fitVids) {
			var $selector = (typeof $selector == 'undefined' ? $('.fit-video') : Wolmart.$(selector).find('.fit-video'));

			$selector.each(function () {
				var $this = $(this),
					$video = $this.find('video'),
					w = $video.attr('width'),
					h = $video.attr('height'),
					cw = $this.outerWidth();

				$video.css({ width: cw, height: cw / w * h });

				if (window.wp.mediaelement) {
					window.wp.mediaelement.initialize();
				}

				$this.fitVids();

				$this.hasClass('d-none') && $this.removeClass('d-none');
			})

			Wolmart.status == 'loading' &&
				window.addEventListener('resize', function () {
					$('.fit-video').fitVids();
				}, { passive: true });
		}
	}

	/**
	 * Run isotopes
	 *
	 * @since 1.0
	 * @param {string} selector
	 * @param {Object} options
	 * @return {void}
	 */
	Wolmart.isotopes = (function () {
		function _isotopeSort(e, $selector) {
			var $grid = $selector ? $selector : $('.grid');

			if (!$grid.length) {
				return;
			}

			$grid.each(function (e) {
				var $this = $(this);
				if (!$this.attr('data-creative-breaks') || $this.hasClass('float-grid')) {
					return;
				}

				$this.children('.grid-item').css({ 'animation-fill-mode': 'none', '-webkit-animation-fill-mode': 'none' });

				var width = window.innerWidth,
					breaks = JSON.parse($this.attr('data-creative-breaks')),
					cur_break = $this.attr('data-current-break');

				if (width >= breaks['lg']) {
					width = '';
				} else if (width >= breaks['md'] && width < breaks['lg']) {
					width = 'lg';
				} else if (width < breaks['md']) {
					width = 'md';
				}

				if (width == cur_break) {
					return;
				}

				if ($this.data('isotope')) {
					$this.isotope({
						sortBy: 'order' + (width ? '_' + width : ''),
					}).isotope('layout');
				} else {
					var options = Wolmart.parseOptions($this.attr('data-grid-options'));
					options.sortBy = 'order' + (width ? '_' + width : '');
					$this.attr('data-grid-options', JSON.stringify(options));
				}
				$this.attr('data-current-break', width);
			});
		}

		return function (selector, options) {
			if (!$.fn.imagesLoaded || !$.fn.isotope) {
				return;
			}
			Wolmart.$(selector).each(function () {
				var $this = $(this);
				if ($this.hasClass('grid-float')) {
					return;
				}

				var settings = $.extend(true, {},
					Wolmart.defaults.isotope,
					Wolmart.parseOptions(this.getAttribute('data-grid-options')),
					options ? options : {},
					$this.hasClass('masonry') ? { horizontalOrder: true } : {}
				);

				_isotopeSort('', $this);

				if (settings.masonry.columnWidth && !$this.children(settings.masonry.columnWidth).length) {
					delete settings.masonry.columnWidth;
				}

				Object.setPrototypeOf(this, HTMLElement.prototype);
				$this.children().each(function () {
					Object.setPrototypeOf(this, HTMLElement.prototype);
				});

				$this.imagesLoaded(function () {
					$this.addClass('isotope-loaded').isotope(settings);
					'undefined' != typeof elementorFrontend && $this.trigger('resize.waypoints');
				});
			});

			Wolmart.$window.on('resize', _isotopeSort);
		}
	})();

	/**
	 * Make sidebar sticky
	 *
	 * @since 1.0
	 * @param {string} selector
	 * @return {void}
	 */
	Wolmart.stickySidebar = function (selector) {
		if ($.fn.themeSticky) {
			Wolmart.$(selector).each(
				function () {
					var $this = $(this),
						aside = $this.closest('.sidebar'),
						options = Wolmart.defaults.stickySidebar,
						top = 0;

					// Do not sticky for off canvas sidebars.
					if (aside.hasClass('sidebar-offcanvas')) {
						return;
					}

					// Add wrapper class
					(aside.length ? aside : $this.parent()).addClass('sticky-sidebar-wrapper');

					$('.sticky-sidebar > .filter-actions').length || $('.sticky-content.fix-top').each(function (e) {
						if ($(this).hasClass('sticky-toolbox')) {
							return;
						}

						var $fixed = $(this).hasClass('fixed');

						top += $(this).addClass('fixed').outerHeight();

						$fixed || $(this).removeClass('fixed');
					});

					// VC Sticky Content
					$('.sticky-sidebar > .filter-actions').length || $('[data-vce-sticky-element=true]').each(function (e) {
						top += $(this).outerHeight();
					});

					options['padding']['top'] = top;

					$this.themeSticky($.extend({}, options, Wolmart.parseOptions($this.attr('data-sticky-options'))));

					// issue: tab change of single product's tab in summary sticky sidebar
					Wolmart.$window.on('wolmart_complete', function () {
						Wolmart.refreshLayouts();
						$this.on('click', '.nav-link', function () {
							setTimeout(function () {
								$this.trigger('recalc.pin');
							});
						});
					});
				}
			);
		}
	}

	/**
	 * Refresh layouts
	 * 
	 * @since 1.0
	 * @return {void}
	 */
	Wolmart.refreshLayouts = function () {
		$('.sticky-sidebar').trigger('recalc.pin');
		Wolmart.$window.trigger('update_lazyload');
	}

	/**
	 * Force lazyLoad
	 *
	 * @since 1.0
	 * @param {jQuery|string} selector
	 * @return {void}
	 */
	Wolmart._lazyload_force = function (selector) {
		Wolmart.$(selector).each(function () {
			var src = this.getAttribute('data-lazy');
			if (src) {
				if (this.tagName == 'IMG') {
					var srcset = this.getAttribute('data-lazyset');
					if (srcset) {
						this.setAttribute('srcset', srcset)
						this.removeAttribute('data-lazyset');
					}
					this.style['padding-top'] = '';
					this.setAttribute('src', src);
					this.classList.remove('w-lazyload');
				} else {
					this.style['background-image'] = 'url(' + src + ')';
				}
				this.removeAttribute('data-lazy');
				this.removeAttribute('data-lazyset');
			}
		})
	}

	/**
	 * LazyLoad
	 *
	 * @since 1.0
	 * @param {jQuery|string} selector
	 * @return {void}
	 */
	Wolmart.lazyload = function (selector) {
		$.fn.lazyload && Wolmart.$(selector, '[data-lazy]').lazyload(Wolmart.defaults.lazyload);
	}

	/**
	 * Initialize price slider
	 * 
	 * @since 1.0
	 * @return {void}
	 */
	Wolmart.initPriceSlider = function () {
		if ($.fn.slider && $('.price_slider').length) {
			$('input#min_price, input#max_price').hide();
			$('.price_slider, .price_label').show();

			var min_price = $('.price_slider_amount #min_price').data('min'),
				max_price = $('.price_slider_amount #max_price').data('max'),
				step = $('.price_slider_amount').data('step') || 1,
				current_min_price = $('.price_slider_amount #min_price').val(),
				current_max_price = $('.price_slider_amount #max_price').val();

			$('.price_slider:not(.ui-slider)').slider({
				range: true,
				animate: true,
				min: min_price,
				max: max_price,
				step: step,
				values: [current_min_price, current_max_price],
				create: function () {
					$('.price_slider_amount #min_price').val(current_min_price);
					$('.price_slider_amount #max_price').val(current_max_price);
					$(document.body).trigger('price_slider_create', [current_min_price, current_max_price]);
				},
				slide: function (e, ui) {
					$('input#min_price').val(ui.values[0]);
					$('input#max_price').val(ui.values[1]);
					$(document.body).trigger('price_slider_slide', [ui.values[0], ui.values[1]]);
				},
				change: function (e, ui) {
					$(document.body).trigger('price_slider_change', [ui.values[0], ui.values[1]]);
				}
			})
		}
	}

	/**
	 * Show loading overlay
	 * 
	 * @since 1.0
	 * @param {string|jQuery} selector 
	 * @param {string} type
	 * @return {void}
	 */
	Wolmart.doLoading = function (selector, type) {
		var $selector = Wolmart.$(selector);
		if (typeof type == 'undefined') {
			$selector.append('<div class="w-loading"><i></i></div>');
		} else if (type == 'small') {
			$selector.append('<div class="w-loading small"><i></i></div>');
		} else if (type == 'simple') {
			$selector.append('<div class="w-loading small"></div>');
		}

		if ('static' == $selector.css('position')) {
			Wolmart.$(selector).css('position', 'relative');
		}
	}

	/**
	 * Hide loading overlay
	 * 
	 * @since 1.0
	 * @param {string|jQuery} selector
	 * @return {void}
	 */
	Wolmart.endLoading = function (selector) {
		Wolmart.$(selector).find('.w-loading').remove();
		Wolmart.$(selector).css('position', '');
	}

	/**
	 * Set current menu items
	 * 
	 * @since 1.0
	 * @param {string|jQuery} selector
	 * @return {void}
	 */
	Wolmart.setCurrentMenuItems = function (selector) {
		if (Wolmart.getUrlParam(location.href, 's')) {
			// if search page
			return;
		}
		var $current = Wolmart.$(selector, 'a[href="' + location.origin + location.pathname + '"]');
		$current.parent('li').each(function () {
			var $this = $(this);
			if ($this.hasClass('menu-item-object-page')) {
				$this.addClass('current_page_item')
					.parent().closest('.mobile-menu li').addClass('current_page_parent')
				$this.parents('.mobile-menu li').addClass('current_page_ancestor');
			}
			$this.addClass('current-menu-item')
				.parent().closest('.mobile-menu li').addClass('current-menu-parent');
			$this.parents('.mobile-menu li').addClass('current-menu-ancestor');
		})
	}

	/**
	 * LazyLoad menu
	 * 
	 * @since 1.0
	 * @return {void}
	 */
	Wolmart.lazyloadMenu = function () {
		// lazyload menu
		var lazyMenus = $('.lazy-menu').map(function () {
			return this.getAttribute('id').slice(5); // remove prefix 'menu-'
		}).get();

		// If lazy menu exists
		if (lazyMenus && lazyMenus.length) {

			// Function to change loaded menu
			function changeLoadedMenu(menuId, menuContent) {
				var $submenus = $(Wolmart.byId('menu-' + menuId)).removeClass('lazy-menu').children('li');
				$(menuContent).filter('li').each(function () {
					var $newli = $(this),
						$oldli = $submenus.eq($newli.index());
					$oldli.children('ul').remove();
					$oldli.append($newli.children('ul'));
				});

				Wolmart.setCurrentMenuItems('#menu-' + menuId);
			}

			// Cache
			var cache = Wolmart.getCache(),
				cachedMenus = cache.menus ? cache.menus : {},
				nonCachedMenus = [];

			// Check if latest menu cache exists
			if (wolmart_vars.lazyload_menu && cache.menus && cache.menuLastTime && wolmart_vars.menu_last_time &&
				parseInt(cache.menuLastTime) >= parseInt(wolmart_vars.menu_last_time)) {

				for (var id in lazyMenus) {
					var menuId = lazyMenus[id];
					if (cachedMenus[menuId]) {
						changeLoadedMenu(menuId, cachedMenus[menuId]);
					} else {
						nonCachedMenus.push(menuId);
					}
				}
			} else {
				// no cache
				nonCachedMenus = lazyMenus;
			}

			// Fetch menus from server 
			if (nonCachedMenus.length) {
				$.ajax({
					type: 'POST',
					url: wolmart_vars.ajax_url,
					dataType: 'json',
					data: {
						action: "wolmart_load_menu",
						menus: nonCachedMenus,
						nonce: wolmart_vars.nonce,
						load_menu: true,
					},
					success: function (menus) {
						if (menus) {
							for (var menuId in menus) {
								var result = menus[menuId];
								if (result) {
									result = result.replace(/(class=".*)current_page_parent\s*(.*")/, '$1$2');
									changeLoadedMenu(menuId, result);
									cachedMenus[menuId] = result;
								}
							}
						}
						Wolmart.menu && Wolmart.menu.addToggleButtons('.collapsible-menu li');
						Wolmart.showEditPageTooltip && Wolmart.showEditPageTooltip();

						// save menu cache
						cache.menus = cachedMenus;
						cache.menuLastTime = wolmart_vars.menu_last_time;
						Wolmart.setCache(cache);
					}
				});
			}
		}
	}

	/**
	 * Disable mobile animations
	 * 
	 * @since 1.0
	 */
	Wolmart.disableMobileAnimations = function () {
		if ($(document.body).hasClass('wolmart-disable-mobile-animation') && window.innerWidth < 768) {
			$('.elementor-invisible').removeAttr('data-settings').removeData('settings').removeClass('elementor-invisible')
				.add($('.appear-animate').removeClass('appear-animate'))
				.add($('[data-vce-animate]').removeAttr('data-vce-animate').removeData('vce-animate'))
		}
	}


	/**
	 * Initialize layouts
	 * 
	 * @since 1.0
	 */
	Wolmart.initLayout = function () {
		Wolmart.fitVideoSize();									// Fit Video Size
		Wolmart.isotopes('.grid');								// Masonry Layout
		Wolmart.stickySidebar('.sticky-sidebar');				// Sticky Sidebar
		Wolmart.lazyload();										// Lazy Load
		Wolmart.lazyloadMenu();									// Lazy Load Menu
		Wolmart.initPriceSlider();								// Initialize price sliders.

		Wolmart.status == 'loading' && (Wolmart.status = 'load');
		Wolmart.$window.trigger('wolmart_load');
		wolmart_vars.resource_after_load ?
			Wolmart.call(Wolmart.initAsync) :
			Wolmart.initAsync();

		if (Wolmart.$body.find('.product').length) {
			Wolmart.$(document).trigger('yith_infs_added_elem');
		}
	}

	/**
	 * Disable mobile animations
	 */
	Wolmart.disableMobileAnimations(); // Disable mobile animations if it's enabled

	/**
	 * Store Swiper Class
	 */
	if (typeof Swiper == 'function') {
		Wolmart.Swiper = Swiper;
	} else {
		var swiperScript;
		swiperScript = document.getElementById('swiper-js');
		if (!swiperScript && wolmart_vars.swiper_url) {
			var s = document.scripts[0];
			swiperScript = document.createElement('script');
			swiperScript.src = wolmart_vars.swiper_url;
			swiperScript = s.parentNode.insertBefore(swiperScript, s);
		}
		if (swiperScript) {
			swiperScript.addEventListener('load', function () {
				Wolmart.Swiper = Swiper;
			})
		}
	}

	/**
	 * Wolmart Theme Setup
	 */
	$(window).on('load', function () {
		// Body has been loaded.
		Wolmart.$body = $(document.body).addClass('loaded');

		// Touch is enabled?
		$('html').addClass('ontouchstart' in document ? 'touchable' : 'untouchable');

		// Run skeleton and init
		if ($.fn.imagesLoaded && typeof Wolmart.skeleton === 'function') {
			if (wolmart_vars.resource_after_load) {
				Wolmart.call(function () {
					Wolmart.skeleton($('.skeleton-body'), Wolmart.initLayout);
				})
			} else {
				Wolmart.skeleton($('.skeleton-body'), Wolmart.initLayout);
			}
		} else {
			if (wolmart_vars.resource_after_load) {
				Wolmart.call(Wolmart.initLayout);
			} else {
				Wolmart.initLayout();
			}
		}
	})
})(jQuery);