<?php
/**
 * The search-form template
 *
 * @package Wolmart WordPress Framework
 * @since 1.0
 */

defined( 'ABSPATH' ) || die;

$options          = $args['aria_label'];
$where            = isset( $options ) && isset( $options['where'] ) ? $options['where'] : '';
$live_search      = (bool) wolmart_get_option( 'live_search' );
$search_type      = isset( $options['type'] ) ? $options['type'] : wolmart_get_option( 'search_form_type' );
$class            = $search_type;
$search_post_type = isset( $options['search_post_type'] ) ? $options['search_post_type'] : ( 'product' == get_post_type() ? 'product' : 'post' );
$icon             = isset( $options['icon'] ) ? $options['icon'] : 'w-icon-search';
if ( isset( $options['placeholder'] ) ) {
	$placeholder = $options['placeholder'];
} else {
	if ( 'post' == $search_post_type ) {
		$placeholder = esc_html__( 'Search in Blog', 'wolmart' );
	} else {
		$placeholder = esc_html__( 'Search', 'wolmart' );
	}
}

if ( '' == $where && ! isset( $options['type'] ) ) {
	$search_type = 'hs-simple';
	$class       = 'hs-simple';
}
?>

<div class="search-wrapper <?php echo esc_attr( $class ); ?>">
	<form action="<?php echo esc_url( home_url() ); ?>/" method="get" class="input-wrapper">
		<input type="hidden" name="post_type" value="<?php echo esc_attr( $search_post_type ); ?>"/>

		<?php if ( 'header' == $where && ( 'hs-expanded' == $search_type ) ) : ?>
		<div class="select-box">
			<?php
			$args = array(
				'show_option_all' => esc_html__( 'All Categories', 'wolmart' ),
				'hierarchical'    => 1,
				'class'           => 'cat',
				'echo'            => 1,
				'value_field'     => 'slug',
				'selected'        => 1,
				'depth'           => 1,
			);
			if ( 'product' == $search_post_type && class_exists( 'WooCommerce' ) ) {
				$args['taxonomy'] = 'product_cat';
				$args['name']     = 'product_cat';
			}
			wp_dropdown_categories( $args );
			?>
		</div>
		<?php endif; ?>

		<input type="search" aria-label="<?php esc_attr_e( 'Search', 'wolmart' ); ?>" class="form-control" name="s" placeholder="<?php echo esc_attr( $placeholder ); ?>" required="" autocomplete="off">

		<?php if ( $live_search ) : ?>
			<div class="live-search-list"></div>
		<?php endif; ?>

		<button class="btn btn-search" aria-label="<?php esc_attr_e( 'Search Button', 'wolmart' ); ?>" type="submit">
			<i class="<?php echo esc_attr( $icon ); ?>"></i>
		</button> 
	</form>
</div>
